@@ -1,7 +1,4 @@
 from django import template
-from pygments import highlight
-from pygments.lexers import get_lexer_by_name
-from pygments.formatters import HtmlFormatter
 
 
 register = template.Library()
