@@ -29,9 +29,6 @@ from django_testscenarios.ubertest import (
     TransactionTestCase,
 )
 from django.contrib.auth.models import User
-from linaro_dashboard_bundle.errors import DocumentFormatError
-from json_schema_validator.errors import ValidationError
-from json_schema_validator.extensions import datetime_extension
 
 
 from dashboard_app.tests import fixtures
