@@ -36,7 +36,7 @@ from lava_results_app.models import (
 )
 from lava_results_app.utils import debian_package_version
 from django.core.exceptions import MultipleObjectsReturned
-from lava_dispatcher.pipeline.action import Timeout
+from lava_dispatcher.action import Timeout
 
 if django.VERSION > (1, 10):
     from django.urls.exceptions import NoReverseMatch
@@ -63,9 +63,7 @@ def _check_for_testset(result_dict, suite):
             suite.job.set_failure_comment(msg)
             logger.warning(msg)
             return None
-        testset, created = TestSet.objects.get_or_create(name=set_name, suite=suite)
-        if created:
-            testset.save()
+        testset, _ = TestSet.objects.get_or_create(name=set_name, suite=suite)
         logger.debug("%s", testset)
     return testset
 
@@ -139,25 +137,12 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
         append_failure_comment(job, msg)
         return False
 
-    suite, created = TestSuite.objects.get_or_create(name=results["definition"], job=job)
-    if created:
-        suite.save()
+    suite, _ = TestSuite.objects.get_or_create(name=results["definition"], job=job)
     testset = _check_for_testset(results, suite)
 
     name = results["case"].strip()
 
     if suite.name == "lava":
-        match_action = None
-        if "level" in results:
-            match_action = ActionData.objects.filter(
-                action_level=str(results['level']),
-                testdata__testjob=suite.job)
-            if match_action:
-                match_action = match_action[0]
-                if 'duration' in results:
-                    match_action.duration = results['duration']
-                if 'timeout' in results:
-                    match_action.timeout = results['timeout']  # duration, positive integer
         try:
             result_val = TestCase.RESULT_MAP[results['result']]
         except KeyError:
@@ -169,17 +154,13 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
         if 'duration' in results:
             measurement = results['duration']
             units = 'seconds'
-        case = TestCase.objects.create(name=name,
-                                       suite=suite,
-                                       test_set=testset,
-                                       metadata=yaml.dump(results),
-                                       measurement=measurement,
-                                       units=units,
-                                       result=result_val)
-        with transaction.atomic():
-            if match_action:
-                match_action.testcase = case
-                match_action.save(update_fields=['testcase', 'duration', 'timeout'])
+        TestCase.objects.create(name=name,
+                                suite=suite,
+                                test_set=testset,
+                                metadata=yaml.dump(results),
+                                measurement=measurement,
+                                units=units,
+                                result=result_val)
 
     else:
         result = results["result"]
@@ -205,8 +186,7 @@ def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-man
                 result=TestCase.RESULT_MAP[result],
                 metadata=yaml.dump(results),
                 measurement=measurement,
-                units=units
-            ).save()
+                units=units)
         except decimal.InvalidOperation:
             logger.exception("[%d] Unable to create test case %s", job.id, name)
     return True
@@ -325,16 +305,20 @@ def build_action(action_data, testdata, submission):
             "type_name failed for %s metatype %s",
             action_data['section'], MetaType.TYPE_CHOICES[metatype])
         return
-    action_meta, created = MetaType.objects.get_or_create(
-        name=type_name, metatype=metatype)
-    if created:
-        action_meta.save()
-    max_retry = None
-    if 'max_retries' in action_data:
-        max_retry = action_data['max_retries']
+    action_meta, _ = MetaType.objects.get_or_create(name=type_name,
+                                                    metatype=metatype)
+    max_retry = action_data.get('max_retries')
+
+    # find corresponding test case
+    match_case = None
+    test_cases = TestCase.objects.filter(suite__job=testdata.testjob, suite__name='lava')
+    for case in test_cases:
+        if 'level' in case.action_metadata:
+            if case.action_metadata['level'] == action_data['level']:
+                match_case = case
 
     # maps the static testdata derived from the definition to the runtime pipeline construction
-    action = ActionData.objects.create(
+    ActionData.objects.create(
         action_name=action_data['name'],
         action_level=action_data['level'],
         action_summary=action_data['summary'],
@@ -342,10 +326,9 @@ def build_action(action_data, testdata, submission):
         action_description=action_data['description'],
         meta_type=action_meta,
         max_retries=max_retry,
-        timeout=int(Timeout.parse(action_data['timeout']))
+        timeout=int(Timeout.parse(action_data['timeout'])),
+        testcase=match_case
     )
-    with transaction.atomic():
-        action.save()
 
 
 def walk_actions(data, testdata, submission):
@@ -383,7 +366,6 @@ def map_metadata(description, job):
         # prevent updates of existing TestData
         logger.debug("[%s] skipping alteration of existing TestData", job.id)
         return False
-    testdata.save()
 
     # get job-action metadata
     if description is None:
@@ -460,6 +442,7 @@ def export_testcase(testcase):
         'result': str(testcase.result_code),
         'measurement': str(testcase.measurement),
         'unit': str(testcase.units),
+        'level': metadata.get('level', ''),
         'url': str(testcase.get_absolute_url()),
         'id': str(testcase.id),
         'logged': str(testcase.logged),
