@@ -15,7 +15,6 @@ from lava_scheduler_app.models import (
     DeviceType,
     Tag,
     TestJob,
-    TemporaryDevice,
     validate_yaml,
     Alias,
 )
@@ -86,226 +85,6 @@ class TestSchedulerAPI(TestCaseWithFactory):  # pylint: disable=too-many-ancesto
         else:
             self.fail("fault not raised")
 
-    def test_submit_job_sets_definition(self):
-        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        user.user_permissions.add(
-            Permission.objects.get(codename='add_testjob'))
-        user.save()
-        server = self.server_proxy('test', 'test')
-        definition = self.factory.make_job_json()
-        try:
-            job_id = server.scheduler.submit_job(definition)
-        except xmlrpclib.Fault as f:
-            self.assertEqual(400, f.faultCode)
-        else:
-            self.fail("v1 job was accepted")
-
-    def test_cancel_job_rejects_anonymous(self):
-        job = self.factory.make_testjob()
-        server = self.server_proxy()
-        try:
-            server.scheduler.cancel_job(job.id)
-        except xmlrpclib.Fault as f:
-            self.assertEqual(401, f.faultCode)
-        else:
-            self.fail("fault not raised")
-
-    def test_cancel_job_rejects_unpriv_user(self):
-        job = self.factory.make_testjob()
-        self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        server = self.server_proxy('test', 'test')
-        try:
-            server.scheduler.cancel_job(job.id)
-        except xmlrpclib.Fault as f:
-            self.assertEqual(403, f.faultCode)
-        else:
-            self.fail("fault not raised")
-
-    def test_cancel_job_cancels_job(self):
-        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        job = self.factory.make_testjob(submitter=user)
-        server = self.server_proxy('test', 'test')
-        server.scheduler.cancel_job(job.id)
-        job = TestJob.objects.get(pk=job.pk)
-        self.assertIn(TestJob.STATUS_CHOICES[job.status], [
-            TestJob.STATUS_CHOICES[TestJob.CANCELED],
-            TestJob.STATUS_CHOICES[TestJob.CANCELING]
-        ])
-
-    def test_cancel_job_user(self):
-        """
-        tests whether the user who canceled the job is reflected properly.
-
-        See: https://bugs.linaro.org/show_bug.cgi?id=650
-        """
-        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        cancel_user = User.objects.create_user('test_cancel',
-                                               'cancel@mail.invalid',
-                                               'test_cancel')
-        cancel_user.save()
-        job = self.factory.make_testjob(submitter=user)
-        job.description = "sample job"
-        job.save()
-        job.cancel(user=cancel_user)
-        job = TestJob.objects.get(pk=job.pk)
-        self.assertIn(TestJob.STATUS_CHOICES[job.status], [
-            TestJob.STATUS_CHOICES[TestJob.CANCELED],
-            TestJob.STATUS_CHOICES[TestJob.CANCELING]
-        ])
-        job = TestJob.objects.get(pk=job.pk)  # reload
-        self.assertEqual(job.failure_comment,
-                         "Canceled by %s" % cancel_user.username)
-
-    def test_json_vs_yaml(self):
-        """
-        Test that invalid JSON gets rejected but valid YAML is accepted as pipeline
-        """
-        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        user.user_permissions.add(
-            Permission.objects.get(codename='add_testjob'))
-        user.save()
-        job = self.factory.make_testjob(submitter=user)
-        self.assertFalse(job.is_pipeline)
-        # "break" the JSON by dropping the closing } as JSON needs the complete file to validate
-        invalid_def = job.definition[:-2]
-        self.assertRaises(ValueError, json.loads, invalid_def)
-        server = self.server_proxy('test', 'test')
-        self.assertRaises(xmlrpclib.Fault, server.scheduler.submit_job, invalid_def)
-
-        invalid_yaml_def = """
-# Sample JOB definition for a KVM
-device_type: qemu
-job_name: kvm-pipeline
-priority: medium
-"""
-        self.assertRaises(ValueError, json.loads, invalid_yaml_def)
-        self.assertRaises(xmlrpclib.Fault, server.scheduler.submit_job, invalid_yaml_def)
-
-        yaml_def = """
-# Sample JOB definition for a KVM
-device_type: qemu
-job_name: kvm-pipeline
-timeouts:
-  job:
-    minutes: 15
-  action:
-    minutes: 5
-priority: medium
-visibility: public
-actions:
-
-    - deploy:
-        to: tmpfs
-        image: http://images.validation.linaro.org/kvm-debian-wheezy.img.gz
-        compression: gz
-        os: debian
-
-    - boot:
-        method: qemu
-        media: tmpfs
-        failure_retry: 2
-
-    - test:
-        name: kvm-basic-singlenode
-        definitions:
-            - repository: git://git.linaro.org/lava-team/lava-functional-tests.git
-              from: git
-              path: lava-test-shell/smoke-tests-basic.yaml
-              # name: if not present, use the name from the YAML. The name can
-              # also be overriden from the actual commands being run by
-              # calling the lava-test-suite-name API call (e.g.
-              # `lava-test-suite-name FOO`).
-              name: smoke-tests
-"""
-        yaml_data = yaml.load(yaml_def)
-        validate_submission(yaml_data)
-        self.assertRaises(xmlrpclib.Fault, server.scheduler.submit_job, yaml_def)
-
-        device_type = self.factory.make_device_type('qemu')
-        device = self.factory.make_device(device_type=device_type, hostname="qemu1")
-        device.save()
-        self.assertFalse(device.is_pipeline)
-        self.assertRaises(xmlrpclib.Fault, server.scheduler.submit_job, yaml_def)
-        device = self.factory.make_device(device_type=device_type, hostname="qemu2", is_pipeline=True)
-        device.save()
-        self.assertTrue(device.is_pipeline)
-        job_id = server.scheduler.submit_job(yaml_def)
-        job = TestJob.objects.get(id=job_id)
-        self.assertTrue(job.is_pipeline)
-
-    def test_health_determination(self):  # pylint: disable=too-many-statements
-        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
-        user.user_permissions.add(
-            Permission.objects.get(codename='add_testjob'))
-        user.save()
-        device_type = self.factory.make_device_type('beaglebone-black')
-        device = self.factory.make_device(device_type=device_type, hostname="black01")
-        device.save()
-        filename = os.path.join(os.path.dirname(__file__), 'sample_jobs', 'master-check.json')
-        self.assertTrue(os.path.exists(filename))
-        with open(filename, 'r') as json_file:
-            definition = json_file.read()
-        # simulate UI submission
-        job = self.factory.make_testjob(definition=definition, submitter=user)
-        self.assertFalse(job.health_check)
-        job.save(update_fields=['health_check', 'requested_device'])
-        self.assertFalse(job.health_check)
-        job.delete()
-        # simulate API submission
-        job = testjob_submission(definition, user)
-        self.assertFalse(job.health_check)
-        self.assertIsNone(job.requested_device)
-        job.delete()
-        job = testjob_submission(definition, user, check_device=None)
-        self.assertFalse(job.health_check)
-        self.assertIsNone(job.requested_device)
-        job.delete()
-        # simulate initiating a health check
-        job = testjob_submission(definition, user, check_device=device)
-        self.assertTrue(job.health_check)
-        self.assertEqual(job.requested_device.hostname, device.hostname)
-        job.delete()
-        # modify definition to use the deprecated target support
-        device2 = self.factory.make_device(device_type=device_type, hostname="black02")
-        device2.save()
-        def_dict = json.loads(definition)
-        self.assertNotIn('target', def_dict)
-        def_dict['target'] = device2.hostname
-        definition = json.dumps(def_dict)
-        # simulate API submission with target set
-        job = testjob_submission(definition, user, check_device=None)
-        self.assertFalse(job.health_check)
-        self.assertEqual(job.requested_device.hostname, device2.hostname)
-        job.delete()
-        # healthcheck designation overrides target (although this is itself an admin error)
-        job = testjob_submission(definition, user, check_device=device)
-        self.assertTrue(job.health_check)
-        self.assertEqual(job.requested_device.hostname, device.hostname)
-        job.delete()
-        # check malformed JSON
-        self.assertRaises(SubmissionException, testjob_submission, definition[:100], user)
-        # check non-existent targets
-        def_dict['target'] = 'nosuchdevice'
-        definition = json.dumps(def_dict)
-        self.assertRaises(Device.DoesNotExist, testjob_submission, definition, user)
-        # check multinode API submission. bug #2130
-        filename = os.path.join(os.path.dirname(__file__), 'sample_jobs', 'master-multinode.json')
-        self.assertTrue(os.path.exists(filename))
-        with open(filename, 'r') as json_file:
-            definition = json_file.read()
-        job_list = testjob_submission(definition, user)
-        self.assertIsInstance(job_list, list)
-        for job in job_list:
-            self.assertIsNotNone(job.vm_group)
-            self.assertFalse(job.health_check)
-            if job.requested_device_type == device_type:
-                self.assertIsNone(job.requested_device)
-            else:
-                self.assertIsNotNone(job.requested_device)
-                self.assertIsInstance(job.requested_device, TemporaryDevice)
-                job.requested_device.delete()
-            job.delete()
-
     def test_new_devices(self):
         user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
         user.user_permissions.add(
@@ -358,7 +137,7 @@ actions:
         Most of the time is spent setting up the database
         and submitting all the test jobs.
         """
-        print >> sys.stderr, timezone.now(), "start"
+        sys.stderr.write(timezone.now(), "start")
         user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
         user.user_permissions.add(
             Permission.objects.get(codename='add_testjob'))
@@ -373,9 +152,9 @@ actions:
             device = self.factory.make_device(device_type=device_type, hostname="imx6q-%s" % suffix)
             device.save()
             count += 1
-        print >> sys.stderr, timezone.now(), "%d dummy devices created" % count
+        sys.stderr.write(timezone.now(), "%d dummy devices created" % count)
         device_list = list(get_available_devices())
-        print >> sys.stderr, timezone.now(), "%d available devices" % len(device_list)
+        sys.stderr.write(timezone.now(), "%d available devices" % len(device_list))
         filename = os.path.join(os.path.dirname(__file__), 'sample_jobs', 'master-check.json')
         self.assertTrue(os.path.exists(filename))
         with open(filename, 'r') as json_file:
@@ -387,17 +166,17 @@ actions:
             job = testjob_submission(definition, user)
             self.assertFalse(job.health_check)
             count += 1
-        print >> sys.stderr, timezone.now(), "%d jobs submitted" % count
+        sys.stderr.write(timezone.now(), "%d jobs submitted" % count)
         jobs = list(get_job_queue())
         self.assertIsNotNone(jobs)
-        print >> sys.stderr, timezone.now(), "Finding devices for jobs."
+        sys.stderr.write(timezone.now(), "Finding devices for jobs.")
         for job in jobs:
             # this needs to stay as a tight loop to cope with load
             device = find_device_for_job(job, device_list)
             if device:
-                print >> sys.stderr, timezone.now(), "[%d] allocated %s" % (job.id, device)
+                sys.stderr.write(timezone.now(), "[%d] allocated %s" % (job.id, device))
                 device_list.remove(device)
-        print >> sys.stderr, timezone.now(), "end"
+        sys.stderr.write(timezone.now(), "end")
 
 
 class TransactionTestCaseWithFactory(TransactionTestCase):
