@@ -30,13 +30,13 @@ from lava_scheduler_app.schema import (
     include_yaml,
     SubmissionException
 )
-from lava_dispatcher.pipeline.device import PipelineDevice
-from lava_dispatcher.pipeline.parser import JobParser
-from lava_dispatcher.pipeline.test.test_defs import check_missing_path
-from lava_dispatcher.pipeline.action import JobError, InfrastructureError
-from lava_dispatcher.pipeline.actions.boot.qemu import BootQEMU
-from lava_dispatcher.pipeline.protocols.multinode import MultinodeProtocol
-from lava_dispatcher.pipeline.test.utils import DummyLogger
+from lava_dispatcher.device import PipelineDevice
+from lava_dispatcher.parser import JobParser
+from lava_dispatcher.test.test_defs import check_missing_path
+from lava_dispatcher.action import JobError, InfrastructureError
+from lava_dispatcher.actions.boot.qemu import BootQEMU
+from lava_dispatcher.protocols.multinode import MultinodeProtocol
+from lava_dispatcher.test.utils import DummyLogger
 from django_restricted_resource.managers import RestrictedResourceQuerySet
 from unittest import TestCase
 
