@@ -1,4 +1,3 @@
-from django.conf import settings
 from django.conf.urls import url
 from lava_scheduler_app.views import (
     active_device_list, active_jobs, device_derestrict_device, device_detail,
@@ -8,20 +7,19 @@ from lava_scheduler_app.views import (
     device_restrict_device, device_type_detail, device_dictionary,
     device_dictionary_plain, device_type_health_history_log,
     device_type_reports, edit_transition, edit_worker_desc,
-    expanded_job_definition, failure_report, favorite_jobs,
+    failure_report, favorite_jobs,
     get_remote_definition, health_job_list, healthcheck, index,
     job_annotate_failure, job_cancel, job_change_priority, job_complete_log,
     job_definition, job_definition_plain, job_description_yaml, job_detail,
-    job_full_log_incremental, job_json, job_list, job_log_file,
-    job_log_file_plain, job_log_incremental, job_log_pipeline_incremental,
-    job_output, job_pipeline_incremental, job_pipeline_sections,
+    job_json, job_list,
+    job_log_file_plain, job_log_pipeline_incremental,
     job_pipeline_timing, job_resubmit, job_section_log, job_status,
-    job_submit, job_toggle_favorite, lab_health, migration,
+    job_submit, job_toggle_favorite, lab_health,
     longest_jobs, multinode_job_definition, multinode_job_definition_plain,
     mydevice_list, mydevices_health_history_log, myjobs, online_device_list,
-    passing_health_checks, pipeline, pipeline_device_list, queue, reports,
-    running, transition_detail, username_list_json, vmgroup_job_definition,
-    vmgroup_job_definition_plain, worker_detail, workers,
+    passing_health_checks, queue, reports,
+    running, transition_detail, username_list_json,
+    worker_detail, workers,
     download_device_type_template, similar_jobs,)
 
 
@@ -32,6 +30,7 @@ urlpatterns = [
     url(r'^edit_worker_desc', edit_worker_desc, name='lava.scheduler.edit_worker_desc'),
     url(r'^activejobs$', active_jobs, name='lava.scheduler.job.active'),
     url(r'^alljobs$', job_list, name='lava.scheduler.job.list'),
+    url(r'^jobsubmit$', job_submit, name='lava.scheduler.job.submit'),
     url(r'^device_type/(?P<pk>[-_a-zA-Z0-9]+)$', device_type_detail,
         name='lava.scheduler.device_type.detail'),
     url(r'^alldevices$', device_list, name='lava.scheduler.alldevices'),
@@ -74,28 +73,8 @@ urlpatterns = [
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/multinode_definition/plain$',
         multinode_job_definition_plain,
         name='lava.scheduler.job.multinode_definition.plain'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/vmgroup_definition$',
-        vmgroup_job_definition,
-        name='lava.scheduler.job.vmgroup_definition'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/vmgroup_definition/plain$',
-        vmgroup_job_definition_plain,
-        name='lava.scheduler.job.vmgroup_definition.plain'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/expanded_definition$',
-        expanded_job_definition,
-        name='lava.scheduler.job.expanded_definition'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/expanded_definition/plain$',
-        vmgroup_job_definition_plain,
-        name='lava.scheduler.job.expanded_definition.plain'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/log_file$', job_log_file,
-        name='lava.scheduler.job.log_file'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/log_file/plain$', job_log_file_plain,
         name='lava.scheduler.job.log_file.plain'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/pipeline_incremental$',
-        job_pipeline_incremental,
-        name='lava.scheduler.job_pipeline_incremental'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/pipeline_sections$',
-        job_pipeline_sections,
-        name='lava.scheduler.job_pipeline_sections'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/timing$',
         job_pipeline_timing,
         name='lava.scheduler.job_pipeline_timing'),
@@ -108,6 +87,8 @@ urlpatterns = [
         name='lava.scheduler.job.section_log'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/cancel$', job_cancel,
         name='lava.scheduler.job.cancel'),
+    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/resubmit$', job_resubmit,
+        name='lava.scheduler.job.resubmit'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/annotate_failure$',
         job_annotate_failure,
         name='lava.scheduler.job.annotate_failure'),
@@ -115,17 +96,9 @@ urlpatterns = [
         job_toggle_favorite,
         name='lava.scheduler.job.toggle_favorite'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/json$', job_json, name='lava.scheduler.job.json'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/output$', job_output,
-        name='lava.scheduler.job.output'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/log_incremental$',
-        job_log_incremental,
-        name='lava.scheduler.job.log_incremental'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/log_pipeline_incremental$',
         job_log_pipeline_incremental,
         name='lava.scheduler.job.log_pipeline_incremental'),
-    url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/full_log_incremental$',
-        job_full_log_incremental,
-        name='lava.scheduler.job.full_log_incremental'),
     url(r'^get-remote-definition', get_remote_definition,
         name='lava.scheduler.get_remote_definition'),
     url(r'^myjobs$', myjobs, name='lava.scheduler.myjobs'),
@@ -143,8 +116,6 @@ urlpatterns = [
         name='lava.scheduler.device.edit_description'),
     url(r'^transition/(?P<pk>[0-9]+)$', transition_detail,
         name='lava.scheduler.transition_detail'),
-    url(r'^alldevices/pipeline$', pipeline_device_list,
-        name='lava.scheduler.pipeline_devices'),
     url(r'^alldevices/active$', active_device_list,
         name='lava.scheduler.active_devices'),
     url(r'^alldevices/online$', online_device_list,
@@ -159,7 +130,6 @@ urlpatterns = [
     url(r'^username-list-json$', username_list_json,
         name='lava.scheduler.username_list_json'),
     url(r'^queue$', queue, name='lava.scheduler.queue'),
-    url(r'^pipeline$', pipeline, name='lava.scheduler.pipeline'),
     url(r'^healthcheck$', healthcheck, name='lava.scheduler.healthcheck'),
     url(r'^running$', running, name='lava.scheduler.running'),
     url(r'^devicehealthhistory/device/(?P<pk>[-_a-zA-Z0-9.]+)',
@@ -175,12 +145,4 @@ urlpatterns = [
         name='lava_scheduler_download_device_type_yaml'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+.[0-9]+)/similarjobs$', similar_jobs,
         name='lava.scheduler.job.similar_jobs'),
-    url(r'^migration$', migration, name='lava.scheduler.migration'),
 ]
-
-if not settings.ARCHIVED:
-    urlpatterns += [
-        url(r'^jobsubmit$', job_submit, name='lava.scheduler.job.submit'),
-        url(r'^job/(?P<pk>[0-9]+|[0-9]+\.[0-9]+)/resubmit$', job_resubmit,
-            name='lava.scheduler.job.resubmit'),
-    ]
