@@ -3,33 +3,19 @@
 """
 This script is particularly intended for those adding new devices to LAVA
 and developing new jinja templates to create the per-device configuration
-in the DeviceDictionary database table.
+in the Device Dictionary database table.
 
-To view database entries, as the lavaserver user, view the current jinja data for
-a specific device:
+In a production system, the devices directory will be stored in
+/etc/lava-server/dispatcher-config/devices/<hostname>.jinja2
 
- lava-server manage device-dictionary --hostname <HOSTNAME> --export
-
-This template can also be turned into a full version of the actual device
-configuration:
-
- lava-server manage device-dictionary --hostname <HOSTNAME> --review
-
-In a production system, the devices directory will not have any files, with
-devices being managed in the database. When developers are working on new support
-directly from the command line lava-dispatch or developing new templates,
-this script can be used to match the template output with existing templates.
+When developers are working on new support directly from the command line
+lava-dispatch or developing new templates, this script can be used to match the
+template output with existing templates.
 
 The path used needs to contain both the jinja2 device-type template in a
 device-types/ directory *and* the jinja2 device dictionary file for the device
 to review in a devices/ directory.
 
-If you use the system path of /etc/lava-server/dispatcher-config/, you'll
-temporarily need to create / symlink your device dictionary file into the
-devices/ directory at that location. This script only looks for device
-configuration files called <HOSTNAME>.jinja2 in the devices/ directory
-specified by the --path option or system path default.
-
 (This script will go into the lava-dev binary package.)
 
 """
